@@ -9,7 +9,7 @@
 #include <string.h>
 #include <stdarg.h>
 
-#define SPVM_NATIVE_VERSION_NUMBER 0.989050
+#define SPVM_NATIVE_VERSION_NUMBER 0.989051
 
 #define SPVM_NATIVE_CREATE_VERSION_STRING_STRINGIFY(x) #x
 
@@ -17,6 +17,10 @@
 
 #define SPVM_NATIVE_VERSION_STRING SPVM_NATIVE_CREATE_VERSION_STRING(SPVM_NATIVE_VERSION_NUMBER);
 
+#define SPVM_NATIVE_GET_POINTER(object) (*(void**)object)
+
+#define SPVM_NATIVE_SET_POINTER(object, pointer) (*(void**)object = pointer)
+
 #define spvm_warn(format, ...) fprintf(stderr, format "\n", ##__VA_ARGS__)
 
 typedef union spvm_value SPVM_VALUE;
@@ -519,10 +523,6 @@ struct spvm_api_mutex {
   void (*reader_unlock)(SPVM_ENV* env, SPVM_VALUE* stack, void* mutex);
 };
 
-SPVM_ENV* SPVM_API_new_env(void);
-
-void SPVM_API_free_env(SPVM_ENV* env);
-
 enum {
   SPVM_NATIVE_C_BASIC_TYPE_ID_UNKNOWN,
   SPVM_NATIVE_C_BASIC_TYPE_ID_UNDEF,
@@ -566,4 +566,8 @@ enum {
   SPVM_NATIVE_C_TYPE_FLAG_MUTABLE = 2,
 };
 
+// These functions are linked only by SPVM itself,
+// so native classes cannot use these functions.
+SPVM_ENV* SPVM_NATIVE_new_env(void);
+
 #endif
