@@ -8,8 +8,8 @@
 
 struct spvm_runtime_basic_type {
   const char* name;
-  const char* module_dir;
-  const char* module_rel_file;
+  const char* class_dir;
+  const char* class_rel_file;
   const char* version_string;
   SPVM_RUNTIME_BASIC_TYPE* parent;
   const char* string_pool;
@@ -19,7 +19,6 @@ struct spvm_runtime_basic_type {
   SPVM_RUNTIME_METHOD* methods;
   SPVM_RUNTIME_METHOD* init_method;
   SPVM_RUNTIME_METHOD* destructor_method;
-  SPVM_RUNTIME_METHOD* required_method;
   SPVM_RUNTIME_BASIC_TYPE** anon_basic_types;
   int32_t id;
   int32_t category;
