@@ -496,7 +496,7 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "RETURN_MULNUM_LONG",
     "RETURN_MULNUM_FLOAT",
     "RETURN_MULNUM_DOUBLE",
-    "ITEMS",
+    "ARGS_WIDTH",
     "CALL_CLASS_METHOD",
     "CALL_INSTANCE_METHOD_STATIC",
     "CALL_INSTANCE_METHOD_DYNAMIC",
